@@ -7,11 +7,15 @@ import {{appname}}.lib.encoders
 import os
 import logging
 import datetime
+import uuid
 
 BASEDIR=os.path.normpath(os.path.join(os.path.dirname(__file__), ".."))
+DATADIR=os.path.join(BASEDIR, "data")
+CERTDIR=os.path.join(DATADIR, "certs")
+LOGDIR=os.path.join(BASEDIR, "log")
 
 server_settings = {
-    "protocol"          :   "http://",
+    "protocol"          :   "http://",      #changed automatically to https depending on ssl: True or False
     "host"              :   "localhost",
     "port"              :   8080,
     "debug"             :   True,
@@ -20,14 +24,18 @@ server_settings = {
     "IOLoop.set_blocking_log_threshold" : 0, 
     "logging"           :   True,
     "analytics_logging" :   False,
-    "https"             :   False,
     "template_path"     :   os.path.join(BASEDIR, "views"),
     "static_url_prefix" :   "/static/",
     "static_path"       :   os.path.join(BASEDIR, "static"),
     "login_url"         :   "/login",
     "xsrf_cookies"      :   False,
     #"log_function"      :   you can give your own log function here.
-    "cookie_secret"     :   "{{cookie_secret}}"
+    "cookie_secret"     :   "{{cookie_secret}}",
+    "ssl"               :   False,
+    "ssl_options"       :   {
+        "certfile"  :   os.path.abspath(os.path.join(CERTDIR, "localhost.crt")),
+        "keyfile"   :   os.path.abspath(os.path.join(CERTDIR, "localhost.key"))
+    }
 }
 
 templates = {
@@ -56,7 +64,7 @@ myapp = {
     "page_size"         :   5,
     "enable_auth"       :   False,   # False, simple or custom
     "sql_auto_schema"   :   True,
-    "logfile"           :   os.path.join(BASEDIR,"pow.log"),
+    "logfile"           :   os.path.join(LOGDIR,"pow.log"),
     "logformat"         :   logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'),
     "id_pattern"        :   "[0-9\-a-zA-Z]+",       # the regex used to math IDs in URLs (uuid in this case)
     "date_format"       :   "%Y-%m-%d",
@@ -79,7 +87,8 @@ database = {
         "boolean"   :   False,
         "datetime"  :   datetime.datetime.utcnow(),
         "dict"      :   {},
-        "binary"    :   None
+        "binary"    :   None,
+        "uuid"      :   None
 
     },
     "sql"   : {
@@ -90,12 +99,12 @@ database = {
         # this is an example for SQlite
         #
         "type"      :   "sqlite", #or: "db+driver" e.g. => "postgres+psycopg2" ...
-        "dbname"    :   os.path.join(BASEDIR, 'db.sqlite'),   # just a name for non file based DBs
+        "dbname"    :   os.path.join(DATADIR, 'db.sqlite'),   # just a name for non file based DBs
         "host"      :   None,     
         "port"      :   None,     
         "user"      :   None,     
         "passwd"    :   None,
-        "enabled"   :   False            
+        "enabled"   :   True            
         #
         # this is an example for Postgres (psycopg2 driver) you can use your preferred driver of course 
         #     
@@ -113,13 +122,24 @@ database = {
         # "dbname"    :   "test",           # just a name for non file based DBs
         # "host"      :   "127.0.0.1",     
         # "port"      :   3306,     
-        # "user"      :   "<you db user here>",
+        # "user"      :   "<your db user here>",
         # "passwd"    :   "<your db pwd here>",
-        # "enabled"   :   False              
+        # "enabled"   :   False    
+        # 
+
+        # # this is an example for MSSQL / pyodbc
+        # "type"      :   "mssql+pyodbc",
+        # "dbname"    :   "<your dbname here>",        # just a name for non file based DBs
+        # "host"      :   "127.0.0.1",     
+        # "port"      :   1433,     
+        # "user"      :   "<your db user here>",
+        # "passwd"    :   "<your db pwd here>",
+        # "driver"    :   "ODBC Driver 17 for SQL Server", # adapt to the driver you installed
+        # "enabled"   :   True                     
 
     },
     "tinydb" : {
-        "dbname"    :   os.path.join(BASEDIR, 'tiny.db'),
+        "dbname"    :   os.path.join(DATADIR, 'tiny.db'),
         "host"      :   None,       
         "port"      :   None,   
         "user"      :   None,
@@ -174,5 +194,5 @@ beta_settings = {
 
 #from handlers.very_raw_own_handler import VeryRawOwnHandler
 routes = [
-            #(r'.*', VeryRawOwnHandler)
+            #(r'.*', VeryRawOwnHandler)  # make sure to enable and adapt the import above as well
 ]
\ No newline at end of file
