@@ -1,6 +1,6 @@
 import os
 from sqlalchemy import Column, Integer, String, DateTime, Float
-from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy.orm import declared_attr
 from sqlalchemy.sql.expression import func 
 from {{appname}}.database.sqldblib import engine,session
 from {{appname}}.lib.powlib import pluralize
