@@ -9,7 +9,7 @@ import os,sys
 import argparse
 
 @task(help={'name': "Name of the test application. Default = testapp"})
-def build(c, path="../..", name="testapp"):
+def generate_and_test(c, path="../..", name="testapp"):
     """
         Create a testapp from the current git version
             generate_app -n <name> -p <path>
@@ -60,7 +60,7 @@ def build(c, path="../..", name="testapp"):
 
 def build_all(c, name, path, force=False):
     """
-        the actual function that does the job
+        the actual function that does the job. 
     """
     print(40*"-")
     print(" starting the build and check...")
@@ -101,8 +101,12 @@ def build_all(c, name, path, force=False):
     test(c,path,name)
     runserver(c,path,name)
 
+
 @task
 def test(c,  path="../..", name="testapp"):
+    """
+        running test in testapp. Or any app given: path and name
+    """
     path=os.path.normpath(path)
     app_path=os.path.abspath(os.path.join(path, name))
     print("app_path: " + app_path)
@@ -125,6 +129,9 @@ def test(c,  path="../..", name="testapp"):
 
 @task
 def runserver(c, path="../..", name="testapp"):
+    """
+     running the pow server in testapp. Or any app given: path and name
+    """
     path=os.path.normpath(path)
     app_path=os.path.abspath(os.path.join(path, name))
     print("app_path: " + app_path)
@@ -155,12 +162,23 @@ def clean(c, path="../..", name="testapp", force=False):
         print(" ..... deleted dir tree: {}".format(app_path))
         print(40*"-")
 
-    
 @task
-def testcliparams(c, name="def"):
+def py_versiontest(c):
     """
-        handing over cli arguments using --parameter_name=value
+        - build the current wheel / dist
+        - run the container (image: pow-ubuntu-python-versiontest) with mounted dist volume
+        - container runs tests automatically
+    """
+    pass
+
+@task
+def testcliparams(c, name="PythonOnWheels" ):
+    """
+        test parameter handover for invoke cli arguments using --parameter_name=value
         try:
                 invoke test --name="somethingelse"
     """
-    print(name)
+    print(f"hello {name}")
+    print(" try: invoke test --name='somethingelse' ")
+
+
